summaryrefslogtreecommitdiffstats
path: root/src/base/Composition.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/base/Composition.h')
-rw-r--r--src/base/Composition.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/base/Composition.h b/src/base/Composition.h
index 24865dd..5a1b0ac 100644
--- a/src/base/Composition.h
+++ b/src/base/Composition.h
@@ -254,7 +254,7 @@ public:
/**
* Test whether a Segment exists in this Composition.
*/
- bool contains(const Segment *);
+ bool tqcontains(const Segment *);
/**
* Return an iterator pointing at the given Segment, or end()
@@ -437,7 +437,7 @@ public:
}
/**
* Return the starting and ending times of the bar that contains
* time t.
*
* Will happily return theoretical timings for bars before the
@@ -770,7 +770,7 @@ public:
//////
//
- // QUANTIZERS
+ // TQUANTIZERS
/**
* Return a quantizer that quantizes to the our most basic
@@ -799,8 +799,8 @@ public:
return m_refreshStatusArray.getNewRefreshStatusId();
}
- RefreshStatus& getRefreshStatus(unsigned int id) {
- return m_refreshStatusArray.getRefreshStatus(id);
+ RefreshtqStatus& getRefreshtqStatus(unsigned int id) {
+ return m_refreshStatusArray.getRefreshtqStatus(id);
}
/// Set all refresh statuses to true
@@ -906,7 +906,7 @@ protected:
std::string getEventType() const { return m_eventType; }
private:
- iterator find(Event *e);
+ iterator tqfind(Event *e);
std::string m_eventType;
};
@@ -989,7 +989,7 @@ protected:
bool m_playMetronome;
bool m_recordMetronome;
- RefreshStatusArray<RefreshStatus> m_refreshStatusArray;
+ RefreshStatusArray<RefreshtqStatus> m_refreshStatusArray;
// User defined markers in the composition
//
@@ -437,7 +437,7 @@ public:
}
/**
- * Return the starting and ending times of the bar that contains
+ * Return the starting and ending times of the bar that tqcontains
* time t.
*